==> med-fichier_2.3.1.orig.tar.gz: med-2.3.1/src/ci/MEDjointInfo.c <==
/*************************************************************************
* COPYRIGHT (C) 1999 - 2003  EDF R&D
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/

#include <med.h>
#include <med_config.h>
#include <med_outils.h>

#include <string.h>
#include <stdlib.h>

med_err
MEDjointInfo(int fid,  char *maa_lcl,  int ind, char *jn, char *des,
             med_int *dom, char *maa_dist)
{
  med_idt jntid;
  med_err ret;
  char chemin[MED_TAILLE_MAA+MED_TAILLE_JNT+MED_TAILLE_NOM+1];
  int num;
  int idx;

  /*
   * On inhibe le gestionnaire d'erreur HDF 5
   */
  _MEDmodeErreurVerrouiller();

  /*
   * On recupere le nom du joint
   */
  num = ind - 1;
  strcpy(chemin,MED_MAA);
  strcat(chemin,maa_lcl);
  strcat(chemin,MED_JNT); 
  if ((idx = _MEDobjetIdentifier(fid,chemin,num,jn)) < 0)
    return -1;

  /* 
   * Si le Data Group JNT n'existe pas => erreur
   */
  strcat(chemin,jn);
  if ((jntid = _MEDdatagroupOuvrir(fid,chemin)) < 0)
      return -1;

  /*
   * L'attribut "DES"
   */
  if ((ret = _MEDattrStringLire(jntid,MED_NOM_DES,MED_TAILLE_DESC,des)) < 0)
    return -1;

  /*
   * L'attribut "MAI"
   */
  if ((ret = _MEDattrStringLire(jntid,MED_NOM_MAI,MED_TAILLE_MAA,maa_dist)) < 0)
    return -1;

  /*
   * L'attribut "DOM"
   */
  if ((ret = _MEDattrEntierLire(jntid,MED_NOM_DOM,dom)) < 0)
    return -1;

  /* 
   * Nombre du nombre de correspondances dans le joint
   */
  /*  *nc = 0;
     _MEDnObjets(fid,chemin,nc);
  */


  /*
   * On ferme tout 
   */
  if ((ret = _MEDdatagroupFermer(jntid)) < 0)
    return -1;

  return ret;
}

==> med-fichier_2.3.5.orig.tar.gz: med-2.3.5/src/ci/MEDjointInfo.c <==
/*************************************************************************
* COPYRIGHT (C) 1999 - 2007  EDF R&D, CEA/DEN
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/

#include <med.h>
#include <med_config.h>
#include <med_outils.h>

#include <string.h>
#include <stdlib.h>

med_err
MEDjointInfo(int fid,  char *maa_lcl,  int ind, char *jn, char *des,
             med_int *dom, char *maa_dist)
{
  med_idt jntid;
  med_err ret;
  char chemin[MED_TAILLE_MAA+MED_TAILLE_JNT+MED_TAILLE_NOM+1];
  int num;
  int idx;

  /*
   * On inhibe le gestionnaire d'erreur HDF 5
   */
  _MEDmodeErreurVerrouiller();

  /*
   * On recupere le nom du joint
   */
  num = ind - 1;
  strcpy(chemin,MED_MAA);
  strcat(chemin,maa_lcl);
  strcat(chemin,MED_JNT); 
  if ((idx = _MEDobjetIdentifier(fid,chemin,num,jn)) < 0)
    return -1;

  /* 
   * Si le Data Group JNT n'existe pas => erreur
   */
  strcat(chemin,jn);
  if ((jntid = _MEDdatagroupOuvrir(fid,chemin)) < 0)
      return -1;

  /*
   * L'attribut "DES"
   */
  if ((ret = _MEDattrStringLire(jntid,MED_NOM_DES,MED_TAILLE_DESC,des)) < 0)
    return -1;

  /*
   * L'attribut "MAI"
   */
  if ((ret = _MEDattrStringLire(jntid,MED_NOM_MAI,MED_TAILLE_NOM,maa_dist)) < 0)
    return -1;

  /*
   * L'attribut "DOM"
   */
  if ((ret = _MEDattrEntierLire(jntid,MED_NOM_DOM,dom)) < 0)
    return -1;

  /* 
   * Nombre du nombre de correspondances dans le joint
   */
  /*  *nc = 0;
     _MEDnObjets(fid,chemin,nc);
  */


  /*
   * On ferme tout 
   */
  if ((ret = _MEDdatagroupFermer(jntid)) < 0)
    return -1;

  return ret;
}
